(function( $ ) {
    'use strict';

    // Create the defaults once
    var pluginName = "helpdesk",
        defaults = {
            bla: "",
        };

    // The actual plugin constructor
    function Plugin ( element, options ) {
        this.element = element;
        this.settings = $.extend( {}, defaults, options );
        this._defaults = defaults;

        this._name = pluginName;
        this.init();
    }

    // Avoid Plugin.prototype conflicts
    $.extend( Plugin.prototype, {
        init: function() {
            var that = this;
            this.window = $(window);
            this.documentHeight = $( document ).height();
            this.windowHeight = this.window.height();

            this.comment_ids = [];
            this.desktopNotifications.comment_ids = [];

            if(this.settings.integrationsWooCommerce == 1){
                this.woocommerceForm();
            }
            if(this.settings.FAQShowSearch == 1){
                this.FAQSearch();
            }
            if(this.settings.enableDesktopNotifications == 1){
                this.desktopNotifications();
            }
            if(this.settings.enableLiveChat == 1){
                this.liveChat();
            }
            if(this.settings.FAQRatingEnable == 1){
                this.FAQRating();
            }
            this.attachments();
        },
        // WooCommerce dynamic fields
        woocommerceForm : function() {

            var links = $('.wordpress-helpdesk-woo-form-show');

            links.on('click', function(e) {
                e.preventDefault();
                var $this = $(this);

                var toShow = $this.data('show');
                $('.wordpress-helpdesk-order-form').addClass('wordpress-helpdesk-hidden');
                $('.wordpress-helpdesk-product-form').addClass('wordpress-helpdesk-hidden');
                $('.wordpress-helpdesk-other-form').addClass('wordpress-helpdesk-hidden');

                $('.wordpress-helpdesk-' + toShow + '-form').removeClass('wordpress-helpdesk-hidden');
                $('.wordpress-helpdesk-form').fadeIn();
            });
        },
        // Add encoding to Comment Form to save attachments
        attachments : function() {
            var comment_form = $('.single-ticket #commentform');

            if(comment_form.length > 0) {
                $('.single-ticket #commentform')[0].encoding = 'multipart/form-data';
            }

            new LuminousGallery($('.wordpress-helpdesk-ticket-attachments a'), {}, {
                caption: function(trigger) {
                  return trigger.querySelector('img').getAttribute('alt');
                }
              });
        },
        // FAQ Search
        FAQSearch : function () {

            var that = this;
            var searchTerms = $('.wordpress-helpdesk-faq-searchterm');
            var delayTimer;

            searchTerms.each(function(i, index) {

                var searchTerm = $(this);
                var resultContainer = searchTerm.siblings('.wordpress-helpdesk-faq-live-search-results');
                
                searchTerm.on('keyup', function(e) {
                    resultContainer.fadeOut();

                    var $this = $(this);
                    var term = $this.val();

                    if(term.length > 2) {
                        clearTimeout(delayTimer);
                        delayTimer = setTimeout(function() {
                            $.ajax({
                                type : 'post',
                                url : that.settings.ajax_url,
                                dataType : 'json',
                                data : {
                                    term : term,
                                    action : 'search_faqs'
                                },
                                success : function( response ) {
                                    if( (searchTerm.attr('name') == "subject") && response.count == 0){
                                        return false;
                                    } else {
                                        resultContainer.fadeIn().html(response.message);
                                    }
                                }
                             });
                        }, 700);
                    }
                });

                $(document).click(function(e) {
                    if ( $(e.target).closest('.wordpress-helpdesk-faq-live-search-results').length === 0 ) {
                        resultContainer.fadeOut();
                    }
                });
            });
        },
        // FAQ Search
        FAQRating : function () {

            var that = this;
            var likeButton = $('.wordpress-helpdesk-faq-rating-like');
            var likeCount = $('#wordpress-helpdesk-faq-rating-like-count');
            var dislikeButton = $('.wordpress-helpdesk-faq-rating-dislike');
            var dislikeCount = $('#wordpress-helpdesk-faq-rating-dislike-count');
            
            likeButton.on('click', function(e) {
               
                e.preventDefault();

                var $this = $(this);
                var post_id = $this.data('post_id');
                $.ajax({
                    type : 'post',
                    url : that.settings.ajax_url,
                    dataType : 'json',
                    data : {
                        post_id : post_id,
                        action : 'count_likes'
                    },
                    success : function( response ) {
                        likeCount.text(response);
                    }
                 });
            });

            if(dislikeButton.length > 0) {
                dislikeButton.on('click', function(e) {
                   
                    e.preventDefault();

                    var $this = $(this);
                    var post_id = $this.data('post_id');
                    $.ajax({
                        type : 'post',
                        url : that.settings.ajax_url,
                        dataType : 'json',
                        data : {
                            post_id : post_id,
                            action : 'count_dislikes'
                        },
                        success : function( response ) {
                            dislikeCount.text(response);
                        }
                     });
                });
            }
        },
        desktopNotifications : function () {

            var that = this;
            var showWelcome = that.getCookie('desktopNotificationsShowWelcome');

            if(that.isEmpty(showWelcome)) {
                Push.create(that.settings.desktopNotificationsWelcomeTitle, {
                        body: that.settings.desktopNotificationsWelcomeText,
                        icon: that.settings.desktopNotificationsIcon,
                        timeout: that.settings.desktopNotificationsTimeout,
                });
                that.createCookie('desktopNotificationsShowWelcome', 'false', that.settings.desktopNotificationsWelcomeTimeout);
            }

            $.ajax( {
                type: 'post',
                url: that.settings.ajax_url,
                dataType: 'json',
                data: {
                    action : 'desktop_notifications_get_comment_ids',
                },
                success: function( response ) {
                    if(response.message == "Not logged in") {
                        return false;
                    }
                    that.desktopNotifications.comment_ids = that.desktopNotifications.comment_ids.concat(response.comment_ids)
                    that.desktopNotificationsInterval = setInterval(function(){ that.desktopNotificationsCheck() }, that.settings.desktopNotificationsAJAXInterval);
                },
                error: function(jqXHR, textStatus, errorThrown) {
                    console.log('An Error Occured: ' + jqXHR.status + ' ' + errorThrown + '! Please contact System Administrator!');
                }
            } );
            
        },
        desktopNotificationsCheck : function() {

            var that = this;
            $.ajax( {
                type: 'post',
                url: that.settings.ajax_url,
                dataType: 'json',
                data: {
                    comment_ids : that.desktopNotifications.comment_ids,
                    action : 'desktop_notifications_get_new_comments',
                },
                success: function( response ) {
                    if(response.status == "false") {
                        return;
                    }
                    that.desktopNotifications.comment_ids.desktop(response.comment_id);

                    Push.create(response.title, {
                        body: response.body,
                        link: response.link,
                        icon: that.settings.desktopNotificationsIcon,
                        timeout: that.settings.desktopNotificationsTimeout,
                    });
                },
                error: function(jqXHR, textStatus, errorThrown) {
                    console.log('An Error Occured: ' + jqXHR.status + ' ' + errorThrown + '! Please contact System Administrator!');
                }
            } );
        },
        liveChat : function() {

            var that = this;

            if($('#wordpress-helpdesk-livechat').length < 1) {
                return;
            }

            that.liveChat.statusContainer = $('#wordpress-helpdesk-livechat-status');
            that.liveChat.chatTriggered = false;
            if($('.wordpress-helpdesk-livechat-reporter').length > 0) {
                that.liveChatHeader();
                that.liveChatTicketForm();
                that.liveChatComment();
                that.liveChatClose();
            }
            if($('.wordpress-helpdesk-livechat-agent').length > 0) {
                that.liveChatAgentHeader(); 
                that.liveChatWatchOpenTickets();
                that.liveChatComment();
                that.liveChatClose();
            }
        },
        liveChatAgentHeader : function() {

            var that = this;
            var header = $('#wordpress-helpdesk-livechat header');

            header.on('click', function() {
                
                if($('.chat').css('display') == "none") {
                    that.liveChat.statusContainer.html('');
                }
                $('.chat').slideToggle(300, 'swing');
                that.liveChatGetOpenChats();
                that.liveChatGetOpenChatsInterval = setInterval(function(){ that.liveChatGetOpenChats() }, that.settings.liveChatAJAXInterval);
            });
        },
        liveChatGetOpenChats : function() {

            var that = this;

            if(that.liveChat.chatTriggered === true) {
                return false;
            }   

            $.ajax({
                type : 'post',
                dataType: 'json',
                url : that.settings.ajax_url,
                data : {
                    action : 'get_open_chats'
                },
                success : function( response ) {
                    var html = "";
                    $('#livechat-open-chats').show();
                    $('#livechat-open-chats-text').html( response.text );
                    $.each(response.chats, function(i, index) {
                        html += '<a href="#" class="livechat-join-chat" data-chat="' + i + '"><div class="chat-message-content livechat-open-chat">' + index + '</div></a>';
                    });
                    $('.livechat-open-chats-chat-container').html(html);
                }
             });
        },
        liveChatWatchOpenTickets : function() {

            var that = this;
            $('.livechat-open-chats-chat-container').on('click', '.livechat-join-chat',  function() {
                clearInterval(that.liveChatGetOpenChatsInterval);
                that.liveChat.chatTriggered = true;
                window.onbeforeunload = that.confirmOnPageExit;
                that.settings.ticket = $(this).data('chat');
                that.liveChatGetTicket(true);
                console.log($('#livechat-open-chats'));
                $('.chat-close').show();
                $('#livechat-open-chats').hide();
                that.liveChatInterval = setInterval(function(){ that.liveChatGetTicket() }, that.settings.liveChatAJAXInterval);
                that.liveChatCheckClosedInterval = setInterval(function(){ that.liveChatWatchClosed() }, that.settings.liveChatAJAXInterval);
            });
        },
        liveChatWatchClosed : function() {
                
            var that = this;
            $.ajax({
                type : 'post',
                url : that.settings.ajax_url,
                dataType : 'json',
                data : {
                    action : 'check_chat_closed',
                    ticket : that.settings.ticket,
                },
                success : function( response ) {
                    
                    if(response.status == "false") {
                        $('.chat-online').hide();
                        that.liveChat.statusContainer.html(response.text);
                        $('#wordpress-helpdesk-livechat .chat-close').trigger('click');
                    }
                }
            });
        },
        liveChatHeader : function() {

            var that = this;
            var header = $('#wordpress-helpdesk-livechat header');

            header.on('click', function() {
                $.ajax({
                    type : 'post',
                    url : that.settings.ajax_url,
                    data : {
                        action : 'get_users_online'
                    },
                    success : function( response ) {
                        if(response > 0) {
                            that.settings.usersOnline = true;
                            $('.chat-online-message').show();
                            $('.livechat-enter-ticket-id').show();
                            $('.wordpress-helpdesk-livechat-title').removeClass('.wordpress-helpdesk-livechat-title-offline').addClass('wordpress-helpdesk-livechat-title-online');
                            if(that.liveChat.chatTriggered === false) {
                                $('.livechat-form-container').fadeIn();
                            }
                        } else {
                            that.settings.usersOnline = false;
                            $('.chat-offline-message').show();
                            $('.livechat-enter-ticket-id').hide();
                            $('.wordpress-helpdesk-livechat-title').removeClass('.wordpress-helpdesk-livechat-title-online').addClass('wordpress-helpdesk-livechat-title-offline');
                            $('.livechat-form-container').fadeIn();
                            $('.chat-offline-message').fadeIn();
                        }
                        that.liveChat.statusContainer.html('');
                        $('.chat').slideToggle(300, 'swing');
                    }
                 });
            });
        },
        liveChatClose : function() {

            var that = this;
            var closeButton = $('#wordpress-helpdesk-livechat .chat-close');

            closeButton.on('click', function(e) {
                e.preventDefault();
                clearInterval(that.liveChatInterval);
                clearInterval(that.liveChatGetOpenChatsInterval);
                clearInterval(that.liveChatCheckClosedInterval);
                $.ajax( {
                    type: 'post',
                    url: that.settings.ajax_url,
                    dataType: 'json',
                    data: {
                        ticket : that.settings.ticket,
                        action : 'close_chat',
                    },
                    success: function( response ) {
                        $('#livechat-open-chats').show();
                        $('.chat-online').hide();
                        $('.chat-close').hide();
                        window.onbeforeunload = null;
                        that.liveChat.chatTriggered = false;
                        that.comment_ids = [];
                        $('#chat-messages').html('');
                    },
                    error: function(jqXHR, textStatus, errorThrown) {
                        console.log('An Error Occured: ' + jqXHR.status + ' ' + errorThrown + '! Please contact System Administrator!');
                    }
                });
            });
        },
        liveChatTicketForm : function() {

            var that = this;
            var ticketForm = $('.livechat-form-container');

            ticketForm.on('submit', function(e) {
                e.preventDefault();

                var username = ticketForm.find('input[name="helpdesk_username"]');
                var email = ticketForm.find('input[name="helpdesk_email"]');
                var subject = ticketForm.find('input[name="helpdesk_subject"]');
                var message = ticketForm.find('input[name="helpdesk_message"]');
                var ticket = ticketForm.find('input[name="ticket"]');

                $('#wordpress-helpdesk-livechat-status').html('');

                if(ticket.length > 0 && !that.isEmpty(ticket.val())) {
                    that.settings.ticket = ticket.val();
                    that.liveChatGetTicket(true);
                    that.setOpenChat(that.settings.ticket);
                    $('.chat-close').show();
                    that.liveChatInterval = setInterval(function(){ that.liveChatGetTicket() }, that.settings.liveChatAJAXInterval);
                    that.liveChatCheckClosedInterval = setInterval(function(){ that.liveChatWatchClosed() }, that.settings.liveChatAJAXInterval);
                } else {
                    if(username.length > 0 && that.isEmpty(username.val())) {
                        username.css('border-color', 'red');
                        return;
                    }
                    if(email.length > 0 && that.isEmpty(email.val())) {
                        email.css('border-color', 'red');
                        return;
                    }
                    if(subject.length > 0 && that.isEmpty(subject.val())) {
                        subject.css('border-color', 'red');
                        return;
                    }
                    if(message.length > 0 && that.isEmpty(message.val())) {
                        message.css('border-color', 'red');
                        return;
                    }

                    $.ajax( {
                        type: 'post',
                        url: that.settings.ajax_url,
                        dataType: 'json',
                        data: {
                            helpdeskTicket : 'Chat',
                            helpdesk_username : username.val(),
                            helpdesk_email : email.val(),
                            helpdesk_subject : subject.val(),
                            helpdesk_message : message.val(),
                            action : 'create_ticket',
                            online : that.settings.usersOnline,
                        },
                        success: function( response ) {

                            if(response.status == "true") {
                                $('.livechat-form-container').fadeOut();
                                $('.chat-online-message').hide();
                                $('.chat-close').show();
                                if(that.settings.usersOnline === true) {
                                    that.liveChat.statusContainer.html(response.message);
                                    that.settings.ticket = response.ticket;
                                    that.liveChatGetTicket(true);
                                    $('.chat-online').fadeIn();
                                    that.setOpenChat(that.settings.ticket);
                                    that.liveChatInterval = setInterval(function(){ that.liveChatGetTicket() }, that.settings.liveChatAJAXInterval);
                                    that.liveChatCheckClosedInterval = setInterval(function(){ that.liveChatWatchClosed() }, that.settings.liveChatAJAXInterval);
                                } else {
                                    var responseContainer = $('.chat-offline-response');
                                    responseContainer.html(response.message).fadeIn();
                                }
                            } else {
                                that.liveChat.statusContainer.html(response.message);
                                return false;
                            }
                        },
                        error: function(jqXHR, textStatus, errorThrown) {
                            console.log('An Error Occured: ' + jqXHR.status + ' ' + errorThrown + '! Please contact System Administrator!');
                        }
                    } );
                }
            });
        },
        setOpenChat : function(ticket) {
            var that = this;

            $.ajax( {
                type: 'post',
                url: that.settings.ajax_url,
                dataType: 'json',
                data: {
                    ticket : ticket,
                    action : 'set_open_chat',
                },
                success: function( response ) {
                    window.onbeforeunload = that.confirmOnPageExit;
                },
                error: function(jqXHR, textStatus, errorThrown) {
                    console.log('An Error Occured: ' + jqXHR.status + ' ' + errorThrown + '! Please contact System Administrator!');
                }
            });
        },
        confirmOnPageExit : function (e) 
        {
            // If we haven't been passed the event get the window.event
            e = e || window.event;

            var message = 'Any text will block the navigation and display a prompt';

            // For IE6-8 and Firefox prior to version 4
            if (e) 
            {
                e.returnValue = message;
            }

            // For Chrome, Safari, IE8+ and Opera 12+
            return message;
        },
        liveChatComment : function() {

            var that = this;
            var commentForm = $('#livechat-comment-form');

            commentForm.on('submit', function(e) {
                e.preventDefault();

                var message = commentForm.find('input[name="helpdesk_message"]');

                if(message.length > 0 && that.isEmpty(message.val())) {
                    message.css('border-color', 'red');
                    return;
                }

                $.ajax( {
                    type: 'post',
                    url: that.settings.ajax_url,
                    dataType: 'json',
                    data: {
                        helpdesk_post_id: that.settings.ticket,
                        helpdesk_message : message.val(),
                        action : 'comment_ticket',
                    },
                    success: function( response ) {
                        if(response.status == "true") {
                            message.val('');
                        } else {
                            console.log('An error occured');
                            console.log(reponse);
                        }
                    },
                    error: function(jqXHR, textStatus, errorThrown) {
                        console.log('An Error Occured: ' + jqXHR.status + ' ' + errorThrown + '! Please contact System Administrator!');
                    }
                } );
            });
        },
        liveChatGetTicket : function(all = false) {

            var that = this;
            
            $.ajax( {  
                type: 'post',
                url: that.settings.ajax_url,
                dataType: 'json',
                data: {
                    comment_ids : that.comment_ids,
                    all : all,
                    ticket : that.settings.ticket,
                    action : 'get_ticket',
                },
                success: function( response ) {
                    if(response.status === "false") {
                        clearInterval(that.liveChatInterval)
                        that.liveChat.statusContainer.html(response.error);
                        return false;
                    }
                    $('.livechat-form-container').fadeOut();
                    $('.chat-online-message').hide();
                    that.liveChat.chatTriggered = true;
                    var responseContainer = $('.chat-online-response');
                    $('.chat-online').fadeIn();
                    that.comment_ids = that.comment_ids.concat(response.comment_ids).filter( that.onlyUnique );


                    if(Object.keys(response.chat).length === 0) {
                        return false;
                    }
                    var html = "";
                    for (var i = 0; i < response.chat.length; i++) {
                        var agentCSS = "";
                        console.log(response.chat[i].agent);
                        if(response.chat[i].agent == true) {
                            var agentCSS = "chat-message-agent";
                        }
                        html += '<div class="chat-message clearfix ' + agentCSS + '">' +
                                     '<div class="chat-message-content clearfix">' +
                                         // '<span class="chat-time">' + response.chat[i]['time'] + '</span>' +
                                         '<h5>' + response.chat[i]['author'] + '</h5>' +
                                         '<p>' + response.chat[i]['content'] + '</p>' +
                                     '</div>' +
                                 '</div>';
                                 // '<hr>';
                    }
                    
                     
                    $('#chat-messages').prepend(html);
                },
                error: function(jqXHR, textStatus, errorThrown) {
                    console.log('An Error Occured: ' + jqXHR.status + ' ' + errorThrown + '! Please contact System Administrator!');
                }
            });
        },
        onlyUnique : function(value, index, self) { 
            return self.indexOf(value) === index;
        },
        //////////////////////
        ///Helper Functions///
        //////////////////////
        isEmpty: function(obj) {

            if (obj == null)        return true;
            if (obj.length > 0)     return false;
            if (obj.length === 0)   return true;

            for (var key in obj) {
                if (hasOwnProperty.call(obj, key)) return false;
            }

            return true;
        },
        sprintf: function parse(str) {
            var args = [].slice.call(arguments, 1),
                i = 0;

            return str.replace(/%s/g, function() {
                return args[i++];

            });
        },
        getCookie: function(cname) {
            var name = cname + "=";
            var ca = document.cookie.split(';');
            for(var i=0; i<ca.length; i++) {
                var c = ca[i];
                while (c.charAt(0)==' ') c = c.substring(1);
                if (c.indexOf(name) === 0) return c.substring(name.length, c.length);
            }
            return "";
        },
        createCookie: function(name, value, minutes) {
            var expires = "";

            if (minutes) {
                var date = new Date();
                date.setTime(date.getTime()+(minutes * 60 * 1000));
                var expires = "; expires="+date.toGMTString();
            }

            document.cookie = name + "=" + value+expires + "; path=/";
        },
    } );

    // Constructor wrapper
    $.fn[ pluginName ] = function( options ) {
        return this.each( function() {
            if ( !$.data( this, "plugin_" + pluginName ) ) {
                $.data( this, "plugin_" +
                    pluginName, new Plugin( this, options ) );
            }
        } );
    };

    $(document).ready(function() {

        $( "body" ).helpdesk( 
            helpdesk_options
        );

    } );

})( jQuery );